@@ -9,7 +9,7 @@
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,14 +20,14 @@
 #ifndef RC5_H
 #define RC5_H
 
-/* 
+/*
  * SILC Crypto API for RC5
  */
 
-SILC_CIPHER_API_SET_KEY(rc5);
-SILC_CIPHER_API_SET_KEY_WITH_STRING(rc5);
-SILC_CIPHER_API_CONTEXT_LEN(rc5);
-SILC_CIPHER_API_ENCRYPT_CBC(rc5);
-SILC_CIPHER_API_DECRYPT_CBC(rc5);
+SILC_CIPHER_API_SET_KEY(rc5_cbc);
+SILC_CIPHER_API_SET_IV(rc5_cbc);
+SILC_CIPHER_API_CONTEXT_LEN(rc5_cbc);
+SILC_CIPHER_API_ENCRYPT(rc5_cbc);
+SILC_CIPHER_API_DECRYPT(rc5_cbc);
 
 #endif
